/// Tests which ensure that the main data structures can be round-tripped faithfully.

use super::*;
use serde_block_tree::{Result, from_vec, to_vec};

static RANDOM_32ARRAY: [u8; 32] = [
    0x75, 0x28, 0xA9, 0xE0, 0x9D, 0x24, 0xBA, 0xB3, 0x79, 0x56, 0x15, 0x68, 0xFD, 0xA4, 0xE2, 0xA4,
    0xCF, 0xB2, 0xC0, 0xE3, 0x96, 0xAE, 0xA2, 0x6E, 0x45, 0x15, 0x50, 0xED, 0xA6, 0xBE, 0x6D, 0xEC,
];

#[test]
fn roundtrip_fragment_record() -> Result<()> {
    let expected = FragmentRecord::new(229, Hash::Sha2_256(RANDOM_32ARRAY));
    let ser_result = to_vec(&expected);
    let de_result = from_vec(&ser_result?);
    assert_eq!(expected, de_result?);
    Ok(())
}

#[test]
fn roundtrip_directory() -> Result<()> {
    let principal = Principal(Hash::Sha2_256(RANDOM_32ARRAY));
    let mut child = HashMap::new();
    child.insert(FragmentSerial(0), FragmentRecord::new(0, principal.0));
    let mut children = HashMap::new();
    children.insert(".metadata".to_string(), child);
    let expected = Directory {
        nodes: vec![Principal(Hash::Sha2_256(RANDOM_32ARRAY))],
        children
    };
    let ser_result = to_vec(&expected);
    let de_result = from_vec(&ser_result?);
    assert_eq!(expected, de_result?);
    Ok(())
}